##  Managing KPIs
Admins can manage KPIs in the KPIs section of the administration area.
  * Edit a KPI: Hover over a KPI, choose the pencil icon on the right, then adjust the KPI parameters as needed and save your changes. Editing a KPI's calculation formula does not recalculate historical values. The change only affects future calculations. You can edit both custom and predefined KPIs.
  * Create a custom KPI by copying an existing one: Hover over a KPI, choose the duplication icon on the right, then adjust the KPI parameters as needed and save your changes.
  * Delete a custom KPI: Hover over a KPI, choose the trash bin icon on the right, then confirm your action. Deleting a KPI removes it from all dashboards where it's displayed. This action cannot be undone. You cannot delete predefined KPIs.
